@@ -1,6 +1,6 @@
 ;; guile-gnome
+;; Copyright (C) 2003,2004,2015 Andy Wingo <wingo at pobox dot com>
 ;; Copyright (C) 2001 Martin Baulig <martin@gnome.org>
-;; Copyright (C) 2003,2004 Andy Wingo <wingo at pobox dot com>
 
 ;; This program is free software; you can redistribute it and/or    
 ;; modify it under the terms of the GNU General Public License as   
@@ -84,8 +84,10 @@
                 gobject-class-get-property-names
                 gobject-get-property gobject-set-property))
 
-(dynamic-call "scm_init_gnome_gobject"
-              (dynamic-link *guile-gnome-gobject-lib-path*))
+(eval-when (expand load eval)
+  (dynamic-call "scm_init_gnome_gobject"
+		(dynamic-link *guile-gnome-gobject-lib-path*)))
+
 
 ;;;
 ;;; {Class Initialization}
@@ -94,10 +96,16 @@
 (define-class <gobject-class> (<gtype-class>))
 
 (define-method (compute-slots (class <gobject-class>))
+  (define (has-slot? name slots)
+    (and (pair? slots)
+         (or (eq? name (slot-definition-name (car slots)))
+             (has-slot? name (cdr slots)))))
   (define (compute-extra-slots props slots)
     (filter-map (lambda (prop)
-                  (and (not (assq prop slots))
-                       `(,prop #:allocation #:gproperty)))
+                  (and (not (has-slot? prop slots))
+                       (if (defined? '<slot>)
+                           (make <slot> #:name prop #:allocation #:gproperty)
+                           `(,prop #:allocation #:gproperty))))
                 props))
   (let* ((slots (next-method))
          (extra (compute-extra-slots
@@ -132,18 +140,19 @@
     ;; We parse a #:gsignal initialization argument to install signals.
     (let loop ((args initargs))
       (if (not (null? args))
-          (if (eq? (car args) #:gsignal)
-              (let ((signal (cadr args)))
-                (if (not (and (list? signal) (>= (length signal) 2)))
-                    (gruntime-error "Invalid signal specification: ~A" signal))
-                (let* ((name (car signal))
-                       (return-type (cadr signal))
-                       (param-types (cddr signal))
-                       (generic (gtype-class-create-signal class name return-type param-types)))
-                  ;; Some magic to define the generic
-                  (module-define! (current-module)
-                                  (generic-function-name generic) generic)))
-              (loop (cddr args))))))
+          (begin
+            (if (eq? (car args) #:gsignal)
+                (let ((signal (cadr args)))
+                  (if (not (and (list? signal) (>= (length signal) 2)))
+                      (gruntime-error "Invalid signal specification: ~A" signal))
+                  (let* ((name (car signal))
+                         (return-type (cadr signal))
+                         (param-types (cddr signal))
+                         (generic (gtype-class-create-signal class name return-type param-types)))
+                    ;; Some magic to define the generic
+                    (module-define! (current-module)
+                                    (generic-function-name generic) generic))))
+            (loop (cddr args))))))
 
   (define (first pred list)
     (cond ((null? list) #f)
@@ -231,6 +240,7 @@ defined on the class, if such a slot is not already defined.
   #:value-type <gobject>
   #:gtype-name "GParamObject")
 
+
 ;;;
 ;;; {GObject Properties}
 ;;;
@@ -277,4 +287,5 @@ calls @code{(slot-ref obj name)}."
       (slot-ref object name)
       (gruntime-error "Properties added after object definition must be accessed via custom property methods: ~A" name)))
 
-(%gnome-gobject-object-post-init)
+(eval-when (load eval)
+  (%gnome-gobject-object-post-init))
