@@ -30,16 +30,6 @@
   #:export-syntax (re-export-modules)
   #:export (export-all-lazy!))
 
-(cond-expand
- (guile-2)
- (else
-  (define-macro (eval-when conditions . forms)
-    (if (or (memq 'eval conditions)
-            (memq 'load conditions))
-        `(begin . ,forms)
-        '(begin)))
-  (export eval-when)))
-
 (define (force-bindings module)
   (cond
    ((and (eq? (module-kind module) 'interface) (module-binder module))
@@ -54,12 +44,13 @@
    (else
     (for-each force-bindings (module-uses module)))))
 
-(and=> (and (not (batch-mode?))
-            (module-variable (resolve-module '(ice-9 session))
-                             'apropos-hook))
-       (lambda (v)
-         (add-hook! (variable-ref v)
-                    (lambda (mod pat) (force-bindings mod)))))
+(eval-when (expand load eval)
+  (and=> (and (not (batch-mode?))
+	      (module-variable (resolve-module '(ice-9 session))
+			       'apropos-hook))
+	 (lambda (v)
+	   (add-hook! (variable-ref v)
+		      (lambda (mod pat) (force-bindings mod))))))
 
 (define-macro (re-export-modules . args)
   "Re-export the public interface of a module; used like
