@@ -43,10 +43,11 @@
 (define-macro (time-debug . forms)
   `(begin ,@forms))
 
-(time-debug (use-modules (gnome gw gdk)))
-(time-debug (use-modules (gnome gw gtk)))
-(re-export-modules (gnome gw gdk)
-                   (gnome gw gtk))
+(eval-when (expand load eval)
+  (time-debug (use-modules (gnome gw gdk)))
+  (time-debug (use-modules (gnome gw gtk)))
+  (re-export-modules (gnome gw gdk)
+		     (gnome gw gtk)))
 
 ;; Support explicit object destruction.
 (define-method (initialize (instance <gtk-object>) initargs)
@@ -89,7 +90,7 @@
 
 ;; Miscellany.
 (define (gtk-tree-or-list-store-set store iter . args)
-  (or (even? (length args)) (scm-error 'gruntime-error "Invalid arguments"))
+  (or (even? (length args)) (scm-error 'gruntime-error #f "Invalid arguments" '() #f))
   (let loop ((args args))
     (if (eq? args '())
         *unspecified*
@@ -106,7 +107,7 @@
 (define (gtk-text-buffer-create-tag buffer tag-name . properties)
   (let ((tag (make <gtk-text-tag> #:name tag-name)))
     (if (not (even? (length properties)))
-        (scm-error 'gruntime-error "Invalid property list: ~A" properties))
+	(scm-error 'gruntime-error #f "Invalid property list: ~A" properties #f))
     (add (get-tag-table buffer) tag)
     (let loop ((props properties))
       (if (null? props)
@@ -116,7 +117,9 @@
             (loop (cddr props)))))))
 (define-method (create-tag (buffer <gtk-text-buffer>) tag-name . properties)
   (apply gtk-text-buffer-create-tag buffer tag-name properties))
-(export create-tag)
+
+(eval-when (expand load eval)
+  (export create-tag))
 
 (define (gtk-stock-id nick)
   (string-append "gtk-" (symbol->string nick)))
